@@ -316,12 +316,15 @@ class HttpRunner(object):
                     self.__execute("teardown", step, variables_mapping, self.__project_meta.functions)
             if globalvar.get_value("toexcel", "") != "":
                 location = ""
+                call = ""
                 for marks in self.pytestmark:
                     if "location" == marks.name:
                         location = marks.args[0]
+                    if "nocall" == marks.name:
+                        call = "无"
                 content = {"dir": self.config.path, "base_url": self.__config.base_url, "url": url_path,
                            "method": method, "name": self.config.name,
-                           "location": location, "curl": a.curl}
+                           "location": location, "call": call, "curl": a.curl}
                 write_excel(content, globalvar.get_value("toexcel"))
 
         return step_data
@@ -434,7 +437,7 @@ class HttpRunner(object):
         self.__session = self.__session or HttpSession()
         # save extracted variables of teststeps
         extracted_variables: VariablesMapping = {}
-
+        # extracted_variables=dict()
         # run teststeps
         for step in self.__teststeps:
             # override variables
@@ -535,6 +538,7 @@ class HttpRunner(object):
         config_variables = self.__config.variables
         if param:
             config_variables.update(param)
+        self.__session_variables = {}
         config_variables.update(self.__session_variables)
         self.__config.name = parse_data(
             self.__config.name, config_variables, self.__project_meta.functions
