@@ -485,7 +485,7 @@ def write_excel(content: Dict, target_dir):
         open = pd.read_excel(file, sheet_name=OPEN)
         ugc = pd.read_excel(file, sheet_name=WEB)
     except:
-        df = pd.DataFrame({"所属服务": [], "method": [], "url": [], "name": [], "界面位置": [], "curl": []})  # 结构
+        df = pd.DataFrame({"所属服务": [], "method": [], "url": [], "name": [], "界面位置": [], "90天是否有调用": [], "curl": []})  # 结构
         writer = pd.ExcelWriter(file, engine="openpyxl")
         df.to_excel(writer, sheet_name=APP, index=False)
         df.to_excel(writer, sheet_name=FRIDAY, index=False)
@@ -500,7 +500,7 @@ def write_excel(content: Dict, target_dir):
 
     tier = get_testcases_tier(content["dir"])
     service = tier[2] if tier[0] == "gateway_api" else ""
-    add_data = [service.replace("_", "-"), content["method"], content["url"], content["name"], content["location"],
+    add_data = [service.replace("_", "-"), content["method"], content["url"], content["name"], content["location"], content["call"],
                 content["curl"]]
 
     with pd.ExcelWriter(file, mode='a', engine='openpyxl', if_sheet_exists='replace') as writer:
